/*
 * Enhydra Java Application Server Project
 *
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
 * the License for the specific terms governing rights and limitations
 * under the License.
 *
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 * $Id: Person.java,v 1.1 2006/02/23 08:47:29 slobodan Exp $
 */

package jtaDiscRack.business.person;

import jtaDiscRack.business.JtaDiscRackBusinessException;
import jtaDiscRack.business.XaTransactionSupport;
import jtaDiscRack.data.person.*;
import com.lutris.appserver.server.sql.DatabaseManagerException;
import com.lutris.dods.builder.generator.query.DataObjectException;
import org.enhydra.dods.exceptions.AssertionDataObjectException;

/**
 * Represents a person.
 */
public class Person extends XaTransactionSupport {

	/*
	 * Person attributes
	 */
	private String handle = null;

	private String firstname = null;

	private String lastname = null;

	private String login = null;

	private String password = null;

	/**
	 * The public constructor.
	 */
	public Person() throws JtaDiscRackBusinessException {

	}

	/** The public constructor
	 *
	 * @param thePerson. The data object of the person.
	 */
	public Person(PersonDO thePerson) throws JtaDiscRackBusinessException {
		try {
			handle = thePerson.get_Handle();
			firstname = thePerson.getFirstname();
			lastname = thePerson.getLastname();
			login = thePerson.getLogin();
			password = thePerson.getPassword();
		} catch (DatabaseManagerException dbme) {
			dbme.printStackTrace();
			throw new JtaDiscRackBusinessException("Error creating Person",
					dbme);
		} catch (DataObjectException doe) {
			doe.printStackTrace();
			throw new JtaDiscRackBusinessException("Error creating Person", doe);
		}
	}

	/**
	 * Gets the object id for the person
	 *
	 * @return the object id.
	 * @exception DiscRackBusinessException if an error occurs
	 *   retrieving data (usually due to an underlying data layer
	 *   error).
	 */
	public String getHandle() throws JtaDiscRackBusinessException {
		return handle;
	}

	/**
	 * Gets the login name for the person
	 *
	 * @return the login name.
	 * @exception DiscRackBusinessException if an error occurs
	 *   retrieving data (usually due to an underlying data layer
	 *   error).
	 */
	public String getLogin() throws JtaDiscRackBusinessException {
		return login;
	}

	/**
	 * Gets the password for the person
	 *
	 * @return the password.
	 * @exception DiscRackBusinessException if an error occurs
	 *   retrieving data (usually due to an underlying data layer
	 *   error).
	 */
	public String getPassword() throws JtaDiscRackBusinessException {
		return password;
	}

	/**
	 * Gets the firstname for the person
	 *
	 * @return the firstname.
	 * @exception DiscRackBusinessException if an error occurs
	 *   retrieving data (usually due to an underlying data layer
	 *   error).
	 */
	public String getFirstname() throws JtaDiscRackBusinessException {
		return firstname;
	}

	/**
	 * Gets the lastname for the person
	 *
	 * @return the lastname.
	 * @exception DiscRackBusinessException if an error occurs
	 *   retrieving data (usually due to an underlying data layer
	 *   error).
	 */
	public String getLastname() throws JtaDiscRackBusinessException {
		return lastname;
	}

	/**
	 * Sets the login name for the person.
	 *
	 * @param the login name.
	 * @exception DiscRackBusinessException if an error occurs
	 *   setting the data (usually due to an underlying data layer
	 *   error).
	 */
	public void setLogin(String login) throws JtaDiscRackBusinessException {
		this.login = login;
	}

	/**
	 * Sets the password for the person.
	 *
	 * @param the password.
	 * @exception DiscRackBusinessException if an error occurs
	 *   setting the data (usually due to an underlying data layer
	 *   error).
	 */
	public void setPassword(String password)
			throws JtaDiscRackBusinessException {
		this.password = password;
	}

	/**
	 * Sets the firstname for the person.
	 *
	 * @param the firstname.
	 * @exception DiscRackBusinessException if an error occurs
	 *   setting the data (usually due to an underlying data layer
	 *   error).
	 */
	public void setFirstname(String firstname)
			throws JtaDiscRackBusinessException {
		this.firstname = firstname;
	}

	/**
	 * Sets the lastname for the person.
	 *
	 * @param the lastname.
	 * @exception DiscRackBusinessException if an error occurs
	 *   setting the data (usually due to an underlying data layer
	 *   error).
	 */
	public void setLastname(String lastname)
			throws JtaDiscRackBusinessException {
		this.lastname = lastname;
	}

	/**
	 * Commits all changes to the database.
	 *
	 * @exception DiscRackBusinessException if an error occurs
	 *   retrieving data (usually due to an underlying data layer
	 *   error).
	 */
	public void save() throws JtaDiscRackBusinessException,
			AssertionDataObjectException {

		initTransaction();

		boolean doCommit = true;

		try {
			PersonDO myDO = PersonDO.createExisting(this.handle);
			if (myDO == null) {
				// person creation
				myDO = PersonDO.createVirgin();
			}

			myDO.setLogin(this.login);
			myDO.setPassword(this.password);
			myDO.setFirstname(this.firstname);
			myDO.setLastname(this.lastname);

			myDO.save();
		} catch (AssertionDataObjectException ex) {
			doCommit = false;
			ex.printStackTrace();
			throw new AssertionDataObjectException(
					"DML opertions not allowed.", ex);
		} catch (Exception ex) {
			doCommit = false;
			ex.printStackTrace();
			throw new JtaDiscRackBusinessException("Error saving person", ex);
		} finally {
			if (doCommit) {
				commitTransaction();
			} else {
				rollbackTransaction();
			}
		}
	}
}
